@@ -46,9 +46,10 @@ setMethod(ShortReadQ, c("DNAStringSet", "BStringSet", "BStringSet"),
             switch(qualityType, Auto={
                 alf <- alphabetFrequency(head(quality, 10000),
                                          collapse=TRUE)
-                if (any(alf) && min(which(alf != 0)) < 59) {
-                    FastqQuality
-                } else SFastqQuality
+                wch <- which(alf != 0)
+                if (any(alf) && (min(wch) >= 58) && (max(wch) > 74)) {
+                    SFastqQuality
+                } else FastqQuality
             }, SFastqQuality=SFastqQuality, FastqQuality=FastqQuality)
         quality <- qualityFunc(quality)
         srq <- 
@@ -170,6 +171,14 @@ setMethod(append, c("ShortReadQ", "ShortReadQ"),
                quality=append(quality(x), quality(values)))
 })
 
+setMethod(reverse, "ShortReadQ", function(x, ...) {
+    ShortReadQ(reverse(sread(x)), reverse(quality(x)), id(x))
+})
+
+setMethod(reverseComplement, "ShortReadQ", function(x, ...) {
+    ShortReadQ(reverseComplement(sread(x)), reverse(quality(x)), id(x))
+})
+
 setMethod(narrow, "ShortReadQ",
     function(x, start=NA, end=NA, width=NA, use.names=TRUE)
 {
